<?php
/*
Plugin Name: References Post Types
Description: Adds custom post type and taxonomies for references
Version: 0.2
Author: LPH
Author Email: layne.heiny@gmail.com
License:

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/

class References_Load {

    /**
     * Constructor
     */
    function __construct() {
        //register an activation hook for the plugin
        register_activation_hook( __FILE__, array( &$this, 'install' ) );

        //Hook up to the init action
        add_action( 'init', array( &$this, 'init' ) );
    }

    /**
     * Runs when the plugin is activated
     */
    function install() {
        $this->init();
        // do not generate any output here
        flush_rewrite_rules();
    }

    /**
     * Runs when the plugin is initialized
     */
    function init() {

        $this->register_post_types();

        $this->register_custom_taxonomies();
    }

    function register_post_types() {

        $labels = array(
            'name' => _x( 'References', 'reference' ),
            'singular_name' => _x( 'Reference', 'reference' ),
            'add_new' => _x( 'Add New', 'reference' ),
            'add_new_item' => _x( 'Add New Reference', 'reference' ),
            'edit_item' => _x( 'Edit Reference', 'reference' ),
            'new_item' => _x( 'New Reference', 'reference' ),
            'view_item' => _x( 'View Reference', 'reference' ),
            'search_items' => _x( 'Search References', 'reference' ),
            'not_found' => _x( 'No references found', 'reference' ),
            'not_found_in_trash' => _x( 'No references found in Trash', 'reference' ),
            'parent_item_colon' => _x( 'Parent Reference:', 'reference' ),
            'menu_name' => _x( 'References', 'reference' ),
        );

        $args = array(
            'labels' => $labels,
            'hierarchical' => false,
            'supports' => array( 'title', 'editor', 'custom-fields', 'thumbnail' ),
            'taxonomies' => array( 'category', 'post_tag' ),
            'public' => true,
            'show_ui' => true,
            'show_in_menu' => true,
            'show_in_nav_menus' => true,
            'publicly_queryable' => true,
            'exclude_from_search' => false,
            'has_archive' => true,
            'query_var' => true,
            'can_export' => true,
            'rewrite' => array( 'slug' => 'references'),
            'capability_type' => 'post'
        );

        register_post_type( 'reference', $args );

    }

    function register_custom_taxonomies() {

         $labels = array(
            'name' => _x( 'Author Name', 'authorname' ),
            'singular_name' => _x( 'Author', 'authorname' ),
            'search_items' => _x( 'Search Authors', 'authorname' ),
            'popular_items' => _x( 'Popular Authors', 'authorname' ),
            'all_items' => _x( 'All Authors', 'authorname' ),
            'parent_item' => _x( 'Parent Author', 'authorname' ),
            'parent_item_colon' => _x( 'Parent Author:', 'authorname' ),
            'edit_item' => _x( 'Edit Author', 'authorname' ),
            'update_item' => _x( 'Update Author', 'authorname' ),
            'add_new_item' => _x( 'Add New Author', 'authorname' ),
            'new_item_name' => _x( 'New Author', 'authorname' ),
            'separate_items_with_commas' => _x( 'Separate Author Names with commas', 'authorname' ),
            'add_or_remove_items' => _x( 'Add or remove Authors', 'authorname' ),
            'choose_from_most_used' => _x( 'Choose from most used Authors', 'authorname' ),
            'menu_name' => _x( 'Authors', 'authorname' ),
        );

        $args = array(
            'labels' => $labels,
            'public' => true,
            'show_in_nav_menus' => true,
            'show_ui' => true,
            'show_tagcloud' => true,
            'hierarchical' => false,
            'rewrite' => array( 'slug' => 'authors'),
            'query_var' => 'author'
        );

        register_taxonomy( 'authorname', array('reference'), $args );

    }



} // end class
new References_Load();

// End references.php